/*
**  lastcall.h (FrontDoor)
**
**  Copyright 1989, 1990 Joaquim H. Homrighausen. All rights reserved.
**
**  Record format for LASTCALL.FD (Last in/outbound call, recent activity)
**
**  Last revision:  90-02-22
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/

/*
**  Recent activity (statistics) definitions.
*/
typedef struct
    {
    word    inbound,                        /* Inbound mail calls */
            outbound,                       /* Outbound mail calls */
            humans,                         /* Inbound BBS callers */
            filesin,                        /* Inbound files */
            filesout,                       /* Outbound files */
            goodsess,                       /* Good sessions */
            badsess,                        /* Failed sessions */
            requests;                       /* Inbound file requests */
    dword   date,                           /* UNIX-style timestamp */
            bytesin,                        /* Inbound (rcvd) bytes */
            bytesout;                       /* Outbound (sent) bytes */
    }
    STATREC, *STATRECPTR;

/*
**  Note that the two char[] fields are in Pascal fashion. The first byte is
**  the length byte. The actual string starts at [1] and the string is NOT
**  NUL terminated. In pascal they would be string[30] and string[40].
*/
typedef struct
    {
    char    system_name[31],
            location[41];
    word    zone,net,node,point;
    dword   time;                           /* UNIX-style timestamp */
    }
    LASTCALL, *LASTCALLPTR;

/*
**  The LASTCALL.FD file contains four records, two STATREC and two
**  LASTCALL. Today's activity is moved to Yesterday's activity as soon
**  as FD runs its 'past-midnight' internal event.
*/
typedef struct
    {
    LASTCALL    lastin,                     /* Last inbound mail call */
                lastout;                    /* Last outbound mail call */
    STATREC     today_act,                  /* Today's activity */
                yesterday_act;              /* Yesterday's activity */
    }
    ACTIVITY, *ACTIVITYPTR;

/* end of file "lastcall.h" */

