/*
**  terminal.h (FrontDoor)
**
**  Copyright 1990 Joaquim H. Homrighausen. All rights reserved.
**
**  Record format for TERMINAL.SYS and TERMKEYS.FD
**
**  Last revision:  90-02-24
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/

/*
**  Record layout for TERMINAL.SYS
**
**  Note that the three char[] fields are in Pascal fashion. The first byte
**  is the length byte. The actual string starts at [1] and the string is
**  NOT NUL terminated. In pascal they would be string[30] and string[8].
*/
#define XLAX_ON     0x00000001L;    /* Use translation table after connect */
#define DIALED      0x00000002L;    /* Queued for dialing, never stored */
#define LINEFEEDS   0x00000004L;    /* CR->CR/LF, otherwise CR->CR */
#define NOWRAPLINES 0x00000008L;    /* Don't wrap lines automatically */
#define B_LOCALECHO 0x00000010L;    /* Echo keyboard input to screen */
#define B_NOAVATAR  0x00000020L;    /* Don't allow Avatar in ANSI emulation */
#define DELETED     0x80000000L;    /* Deleted entry, never stored */

typedef struct
    {
    char    name[31],               /* Name of system */
            number[31];             /* Telephone number */
    word    baud;                   /* 300..38400 */
    dword   flags;                  /* See above */
    byte    protocol,               /* 0=Zmodem, 1=Xmodem, 2=Telink */
            parity,                 /* 0=No, 1=Odd, 2=Even */
            wordlen,                /* 7/8 */
            stopbits,               /* 1/2 */
            emulation;              /* 1=TTY, 2=ANSI, 3=VT52, 4=VT100 */
    word    keyset;                 /* Key definition, 65535==default */
    char    scriptname[9];          /* Script name to use, blank if none */
    }
    PHONEREC, *PHONERECPTR;

/*
**  Record layout for TERMKEYS.FD
**
**  Note that the char[] fields are in Pascal fashion. The first byte
**  is the length byte. The actual string starts at [1] and the string is
**  NOT NUL terminated. In pascal they would be string[30].
*/
typedef struct
    {
    char    shiftkey[12][31],       /* Shift F1-F12 */
            ctrlkey[12][31];        /* Ctrl F1-F12 */
    }
    KEYREC, *KEYRECPTR;

/* end of file "terminal.h" */

